@@ -145,7 +145,7 @@ class UserGroupService(object):
             is_remove_empty=True
         )
         if user_search_params:
-            user_serv, err = UserService.user_list(params=user_search_params, need_Pagination=False)
+            user_serv, err = UserService.user_list(params=user_search_params, need_Pagination=False, is_strict_mode=False)
             params["user_id_list"] = [i["user_id"] for i in user_serv if i]
 
         # 是否需要子节点搜索
@@ -155,11 +155,15 @@ class UserGroupService(object):
             if err:
                 return None, err
             params["user_group_id_list"] = JRecur.get_value_in_forest(group_id_tree)
+            params.pop("group_id", None)
+            params.pop("user_group_id", None)
+
         # 分组下面用户分页查询
         group_search_params = format_params_handle(
             param_dict=params,
             filter_filed_list=["group_id", "user_group_id", "user_group_id_list", "user_id", "user_id_list"],
-            alias_dict={"user_group_id_list": "user_group_id__in", "group_id": "user_group_id", "user_id_list": "user_id__in"}
+            alias_dict={"user_group_id_list": "user_group_id__in", "group_id": "user_group_id", "user_id_list": "user_id__in"},
+            is_remove_empty=True
         )
         # 边界查询,分组(部门)必传
         # if not group_search_params:
@@ -203,9 +207,9 @@ class UserGroupService(object):
             return None, "参数错误，user_id, group_id 必传"
         try:
             UserToGroup.objects.get_or_create(
-                {"user_id": user_id, "group_id": group_id},
+                {"user_id": user_id, "user_group_id": group_id},
                 user_id=user_id,
-                group_id=group_id,
+                user_group_id=group_id,
             )
             return None, None
         except Exception as e:
@@ -222,7 +226,7 @@ class UserGroupService(object):
         # 如果传控制则表示
         if not group_list:
             UserToGroup.objects.filter(user_id=user_id).delete()
-            return None, "msg:ok;tip:至少选择一个部门"
+            return None, None
 
         group_list = group_list.split(',') if isinstance(group_list, str) else group_list
         sid = transaction.savepoint()
@@ -422,10 +426,20 @@ class UserGroupService(object):
     @staticmethod
     def group_user_edit(params):  # 更名或者单独起一个文件 方法这个方法
         # 用户角色部门绑定
-        user_role_list = params.get('user_role_list', None)
-        user_group_list = params.get('user_group_list', None)
-        UserGroupService.user_bind_groups(params.get("user_id"), user_group_list)
-        RoleService.bind_user_role(params.get("user_id"), user_role_list)
-        return None, None
+        user_role_list = params.get('user_role_id_list', None)
+        user_group_list = params.get('user_group_id_list', None)
+        user_id = params.get("user_id")
+        if not user_id:
+            return None, "msg:用户ID错误;tip:非法请求"
+        if not user_group_list is None:
+            data, err = UserGroupService.user_bind_groups(params.get("user_id"), user_group_list)
+            if err:
+                return None, "msg:" + str(err).replace(":", " ") + ";tip:部门修改异常"
 
+        if not user_role_list is None:
+            data, err = RoleService.bind_user_role(params.get("user_id"), user_role_list)
+            if err:
+                return None, "msg:" + str(err).replace(":", " ") + ";tip:角色修改异常"
+
+        return None, None
     # ===============  用户分组和角色关系操作服务 start ===============
